@@ -315,7 +315,7 @@ def pack (file_list, output):
 
     console.confirm(" %s packed" % output)
 
-def unpack (pack_file, output):
+def unpack (pack_file, output, extract = None):
     
     console.header( "- Unpacking %s to %s " % (pack_file, output))
 
@@ -329,8 +329,15 @@ def unpack (pack_file, output):
 
     count = 0
     for fname in comp:
+        if extract and extract not in fname:
+            continue
+
         data = comp.extract(fname)
         
+        #folder
+        if not data:
+            continue
+
         output_file = os.path.join(output, fname)
         console.info(' + %s' % __pretty(output_file))
         writefile(output_file, data)
